| Title: | 'Rcpp' Bindings for the Google 'Benchmark' Library |
|---|---|
| Description: | The Google 'Benchmark' library provides a framework for microbenchmarking C++ code. This packages makes it accessible from R. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-29 19:36:22 UTC |
| Source: | https://github.com/eddelbuettel/rcppbenchmark |
The Google 'Benchmark' library provides a framework for microbenchmarking C++ code. This packages makes it accessible from R.
The DESCRIPTION file:
| Package: | RcppBenchmark |
| Type: | Package |
| Title: | 'Rcpp' Bindings for the Google 'Benchmark' Library |
| Version: | 0.0.1 |
| Date: | 2017-03-01 |
| Author: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| Description: | The Google 'Benchmark' library provides a framework for microbenchmarking C++ code. This packages makes it accessible from R. |
| License: | GPL (>= 2) |
| Imports: | Rcpp |
| LinkingTo: | Rcpp |
| RoxygenNote: | 6.0.1 |
| Repository: | https://eddelbuettel.r-universe.dev |
| Date/Publication: | 2024-08-20 13:15:35 UTC |
| RemoteUrl: | https://github.com/eddelbuettel/rcppbenchmark |
| RemoteRef: | HEAD |
| RemoteSha: | 988ea04ca0879647e66bae9c5af21d18670dcd8a |
Index of help topics:
example0 Simple Google Benchmark micro-benchmarking
examples
RcppBenchmark-package 'Rcpp' Bindings for the Google 'Benchmark'
Library
This section should provide a more detailed overview of how to use the package, including the most important functions.
Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
This optional section can contain literature or other references for background information.
Optional links to other man pages
## Optional simple examples of the most important functions ## Use \dontrun{} around code to be shown but not executed## Optional simple examples of the most important functions ## Use \dontrun{} around code to be shown but not executed
Simple microbenchmarking examples
example0()example0()
None